pub struct MemoryPressureSignalRequest {
pub level: Level,
}Fields
level: LevelTrait Implementations
Sourceimpl Clone for MemoryPressureSignalRequest
impl Clone for MemoryPressureSignalRequest
Sourcefn clone(&self) -> MemoryPressureSignalRequest
fn clone(&self) -> MemoryPressureSignalRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for MemoryPressureSignalRequest
Sourceimpl Debug for MemoryPressureSignalRequest
impl Debug for MemoryPressureSignalRequest
Sourceimpl<D: ResourceDialect> Decode<MemoryPressureSignalRequest, D> for MemoryPressureSignalRequest
impl<D: ResourceDialect> Decode<MemoryPressureSignalRequest, D> for MemoryPressureSignalRequest
Sourceimpl<D: ResourceDialect> Encode<MemoryPressureSignalRequest, D> for &MemoryPressureSignalRequest
impl<D: ResourceDialect> Encode<MemoryPressureSignalRequest, D> for &MemoryPressureSignalRequest
Sourceimpl<D: ResourceDialect, T0: Encode<Level, D>> Encode<MemoryPressureSignalRequest, D> for (T0,)
impl<D: ResourceDialect, T0: Encode<Level, D>> Encode<MemoryPressureSignalRequest, D> for (T0,)
impl Eq for MemoryPressureSignalRequest
Sourceimpl Hash for MemoryPressureSignalRequest
impl Hash for MemoryPressureSignalRequest
Sourceimpl Ord for MemoryPressureSignalRequest
impl Ord for MemoryPressureSignalRequest
Sourcefn cmp(&self, other: &MemoryPressureSignalRequest) -> Ordering
fn cmp(&self, other: &MemoryPressureSignalRequest) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for MemoryPressureSignalRequest
impl PartialEq for MemoryPressureSignalRequest
Sourcefn eq(&self, other: &MemoryPressureSignalRequest) -> bool
fn eq(&self, other: &MemoryPressureSignalRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for MemoryPressureSignalRequest
impl PartialOrd for MemoryPressureSignalRequest
impl Persistable for MemoryPressureSignalRequest
impl StructuralPartialEq for MemoryPressureSignalRequest
Sourceimpl TypeMarker for MemoryPressureSignalRequest
impl TypeMarker for MemoryPressureSignalRequest
Sourcetype Owned = MemoryPressureSignalRequest
type Owned = MemoryPressureSignalRequest
The owned Rust type which this FIDL type decodes into.
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.Sourceimpl ValueTypeMarker for MemoryPressureSignalRequest
impl ValueTypeMarker for MemoryPressureSignalRequest
Sourcetype Borrowed<'a> = &'a MemoryPressureSignalRequest
type Borrowed<'a> = &'a MemoryPressureSignalRequest
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &Self::Owned. There are three cases: Read moreAuto Trait Implementations
impl Freeze for MemoryPressureSignalRequest
impl RefUnwindSafe for MemoryPressureSignalRequest
impl Send for MemoryPressureSignalRequest
impl Sync for MemoryPressureSignalRequest
impl Unpin for MemoryPressureSignalRequest
impl UnsafeUnpin for MemoryPressureSignalRequest
impl UnwindSafe for MemoryPressureSignalRequest